#!/bin/bash
#
# ===== backup-host scripts ======
#
# acl-backup.sh: backup of ntfs ACL
#
# $Rev: 72 $
# $Date: 2012-09-11 08:39:13 +0200 (mar, 11 set 2012) $
# $Author: resolir $
#
#	Copyright (C) 2011-2012 Roberto Resoli - Comune di Trento;
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; version 3
#	of the License.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place - Suite 330, Boston, 
#	MA  02111-1307, USA.
#

source "/usr/share/backuppc-bcs/bin/acl-functions"

if [ $# -ne 1 ]; then
    log "Path parameter is required!"
    exit 1
fi

#Force trailing slash
ACL_TARGET="$1"/
ACL_TARGET=${ACL_TARGET/%"//"//}

if [ ! -d "$ACL_TARGET" ]; then
    log "$ACL_TARGET is not an existent directory!"
    exit 1
fi


log "--- acls backup ---"

ACL_TARGET_WIN=$(cyg_2_win "$ACL_TARGET")
ACL_FILE=$ACL_TARGET.acl.bak
ACL_FILE_WIN=$(cyg_2_win "$ACL_FILE")

remove_if_exists "$ACL_FILE" 
remove_if_exists "$ACL_FILE".err

log "Dumping acls for $ACL_TARGET to $ACL_FILE ..."
log "Executing: SetACL.exe -on ${ACL_TARGET_WIN/%\/\\} -ot file -actn list -lst f:sddl;w:d,s,o,g -bckp ${ACL_TARGET_WIN/%\/\\}.acl.bak -rec cont_obj -silent -ignoreerr "

#Note that some escaping is needed (-lst flags ...) 
#in order to launch SetACL directly from bash
"$SETACL_CMD" \
	-on "${ACL_TARGET_WIN/%\/\\}" \
	-ot file \
	-actn list \
	-lst f:sddl\;w:d,s,o,g \
	-bckp "${ACL_TARGET_WIN/%\/\\}.acl.bak" \
	-rec cont_obj \
	-silent \
	-ignoreerr 
echo "$?" >  "$ACL_FILE.err"

#log file no more generated
#unicode_grep "$ACL_FILE".log "^ERROR" "$ACL_FILE".err
#remove_if_exists "$ACL_FILE".log

log "Setting $ACL_FILE_WIN as hidden"
attrib.exe +H "$ACL_FILE_WIN"
log "Setting $ACL_FILE_WIN.err as hidden"
attrib.exe +H "$ACL_FILE_WIN".err
log "--- acls backup ok. ---"
exit 0
