#!/bin/bash
#
# ===== backup-host scripts ======
#
# acl-restore.sh: restore of ntfs ACL
#
# $Rev: 73 $
# $Date: 2012-09-11 08:47:49 +0200 (mar, 11 set 2012) $
# $Author: resolir $
#
#	Copyright (C) 2011-2012 Roberto Resoli - Comune di Trento;
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; version 3
#	of the License.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place - Suite 330, Boston, 
#	MA  02111-1307, USA.
#
source "/usr/share/backuppc-bcs/bin/acl-functions"

if [ $# -lt 4 ]; then
    log "SHARE, BACKUP_BASE, RESTORE_BASE and one or more FILE parameters are required!"
    exit 1
fi

if [ ! -d "$1" ]; then
    log "SHARE \"$1\" is not an existent directory!"
    exit 1
fi

log "--- acl restore ---"
log "Original cmd: $SSH_ORIGINAL_COMMAND"

SHARE="$1"
BACKUP_BASE="$2"
RESTORE_BASE="$3"
FILTER=""
WIN_TARGETS=();
WIN_RTARGETS=();
while [ ! -z "$4" ]; do
  W_PATH=$(cyg_2_win "$SHARE$4")
  WIN_TARGETS=( "${WIN_TARGETS[@]}" "$W_PATH" )
  R_LEAF="${4#"$BACKUP_BASE"}"
  W_RPATH=$(cyg_2_win "$SHARE$RESTORE_BASE$R_LEAF")
  WIN_RTARGETS=( "${WIN_RTARGETS[@]}" "$W_RPATH" )
  FILTER=${W_PATH//'\'/[\\]}"\|""$FILTER"
 shift
done

log "Backup targets: $WIN_TARGETS"
log "Restore targets: $WIN_RTARGETS"

FILTER=${FILTER/%"\|"/}

ACL_FILE="$SHARE"/.acl.bak
if [ ! -f "$ACL_FILE"  ]; then 
   log "No acl file!"
  exit 1
fi
log "$ACL_FILE found!"

ACL_FILE_WIN=$(cyg_2_win "$ACL_FILE")

WIN_PATH=$(cyg_2_win "$SHARE""$RESTORE_BASE")

ACL_RESTORE_FILE="$SHARE""$RESTORE_BASE".acl.rst
ACL_RESTORE_FILE_WIN=$(cyg_2_win "$ACL_RESTORE_FILE")

log "Extracting acls from $ACL_FILE into $ACL_RESTORE_FILE ..."
if [ -f "$ACL_RESTORE_FILE" ]; then 
  log "Removing existing $ACL_RESTORE_FILE"
  rm "$ACL_RESTORE_FILE" 
fi
if [ -f "$ACL_RESTORE_FILE".err ]; then 
  log "Removing existing $ACL_RESTORE_FILE".err
  rm "$ACL_RESTORE_FILE".err 
fi

log "Executing: unicode_grep $ACL_FILE $FILTER $ACL_RESTORE_FILE $SHARE$BACKUP_BASE $SHARE$RESTORE_BASE "
unicode_grep "$ACL_FILE" "$FILTER" "$ACL_RESTORE_FILE" "$SHARE$BACKUP_BASE" "$SHARE$RESTORE_BASE"


log "Setting $ACL_RESTORE_FILE as hidden"
attrib.exe +H "$ACL_RESTORE_FILE_WIN"

#OWNER SETTING - Override owner for permitting acl restore
for WIN_RTARGET in "${WIN_RTARGETS[@]}"
do
  log "Setting owner for \"$WIN_RTARGET\" contents ..."
  SET_OWNR_CMD="$SETACL_CMD -on  ${WIN_RTARGET/%\\/} -ot file -actn setowner -ownr n:administrators -rec cont_obj -silent -ignoreerr "
  log "Executing: \"$SET_OWNR_CMD\" "

  "$SETACL_CMD" \
	-on "${WIN_RTARGET/%\\/}" \
	-ot file \
	-actn setowner \
	-ownr n:administrators \
	-rec cont_obj \
	-silent \
	-ignoreerr \
	-log "$ACL_RESTORE_FILE_WIN".log > /dev/null 2>&1

done

log "Restoring acls for \"$WIN_PATH\" contents ..."
RST_CMD="SetACL.exe -on 'dummy' -ot file -actn restore -silent -ignoreerr -bckp "
log "Executing: \"$RST_CMD $ACL_RESTORE_FILE_WIN\" "
"$SETACL_CMD" \
	-on 'dummy' \
	-ot file \
	-actn restore \
	-silent \
	-ignoreerr \
	-bckp "$ACL_RESTORE_FILE_WIN" \
	-log "$ACL_RESTORE_FILE_WIN".log > /dev/null 2>&1

unicode_grep "$ACL_RESTORE_FILE".log "^ERROR" "$ACL_RESTORE_FILE".err

if [ -f "$ACL_RESTORE_FILE".log ]; then 
  log "Removing existing $ACL_RESTORE_FILE".log
  rm "$ACL_RESTORE_FILE".log 
fi

log "Setting $ACL_RESTORE_FILE.err as hidden"
attrib.exe +H "$ACL_RESTORE_FILE_WIN".err

log "--- acl restore ok. ---"

exit 0
