#!/bin/bash
#
# ===== backup-host scripts ======
#
# snap.sh: utility for interactive snapshot creation/removal
#
# $Rev: 73 $
# $Date: 2012-09-11 08:47:49 +0200 (mar, 11 set 2012) $
# $Author: resolir $
#
#	Copyright (C) 2011-2012 Roberto Resoli - Comune di Trento;
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; version 3
#	of the License.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place - Suite 330, Boston, 
#	MA  02111-1307, USA.
#
HOST_CONF=/usr/share/backuppc-bcs/host.conf
SNAP_FUNCTIONS=/usr/share/backuppc-bcs/bin/snap-functions

source $HOST_CONF
source $SNAP_FUNCTIONS

#GREP_CMD=$(which grep)
#The above could detect a non cygwin grep, so filter out 
#paths containing "cygdrive"
for i in $(which -a grep)
do 
  if [ $(expr match "$i" ".*cygdrive.*") -eq 0 ]; then
	GREP_CMD=$i; 
	break; 
  fi
done


ID_BKP=/usr/share/backuppc-bcs/bin/id_rsa_backup
SSH_CMD="$(which ssh) -i $ID_BKP"

get_pve() {
   for a_pve in $PVE_LIST
   do
	local status=$($SSH_CMD -n -l root "$a_pve" "qm status $VMID" 2>&1)
	if [ "$status" == "status: running" ] || [ "$status" == "running" ] ; then
	   echo -n "$a_pve"
	   return 0
   	fi
   done
   return 1
}

if [ $# -lt 2 ]; then
    echo "Action and Share parameters are required!"
    exit 1
fi
if [ ! -e "$ID_BKP" ]; then
    echo "Backup ssh key \"$ID_BKP\" is missing!"
    exit 1
fi


REL_MOUNT="$2"
SNAP_PARAMS=$($GREP_CMD " $REL_MOUNT " $HOST_CONF)
SNAP_PARAMS=${SNAP_PARAMS/##/}

echo "GREP_CMD: \"$GREP_CMD\"" 
echo "SSH_CMD: \"$SSH_CMD\""
echo "SNAP_PARAMS: \"$SNAP_PARAMS\""

if [ "$SNAP_PARAMS" == "" ]; then
    echo "No SNAP_PARAMS! Have you specified the mountpoint with a trailing slash?"
    exit 1
fi

VMID=$( echo "$SNAP_PARAMS" | cut -d' ' -f1 )

PVE_HOST=$(get_pve)

EXIT_CODE=999
if [ "$PVE_HOST" == "" ]; then
 exit $EXIT_CODE
fi 

#Set "NO_TASKS" to false for doing 
#a more complete test (be warned that this could trigger
#operations such as stop services, lock databases ...)
NO_TASKS=true

case "$1" in
create)
	if [ -e tasks ] && [ "$NO_TASKS" == "true" ]; then 
		echo "NO_TASKS=$NO_TASKS , renaming 'tasks' file to 'tasks.no'"
		mv tasks tasks.no
	fi

	before_snap "$REL_MOUNT" 2>&1
	echo "Creating snapshot on: $PVE_HOST -> $SNAP_PARAMS" 
	$SSH_CMD -n -l root $PVE_HOST "snap-create.sh $SNAP_PARAMS" 2>&1
	EXIT_CODE=$?
	after_snap 2>&1

	if [ -e tasks.no ] && [ $NO_TASKS ]; then 
		echo "NO_TASKS=$NO_TASKS , reverting 'tasks.no' file to 'tasks'"
		mv tasks.no tasks
	fi
;;
remove)
	echo "Removing snapshot on: $PVE_HOST -> $SNAP_PARAMS" 
	$SSH_CMD -n -l root $PVE_HOST "snap-remove.sh $SNAP_PARAMS" 2>&1
	EXIT_CODE=$?
;;
*)
	echo "Action $1 not defined."
;;
esac 


exit $EXIT_CODE

